# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_enrol_get_potential_users_response_inner import CoreEnrolGetPotentialUsersResponseInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModAssignGetParticipantResponse(BaseModel):
    """
    ModAssignGetParticipantResponse
    """ # noqa: E501
    allowsubmissionsfromdate: Optional[StrictInt] = Field(description="allowsubmissionsfromdate for the user")
    blindmarking: Optional[StrictBool] = Field(description="is blind marking enabled for this assignment")
    cutoffdate: Optional[StrictInt] = Field(description="cutoffdate for the user")
    duedate: Optional[StrictInt] = Field(description="duedate for the user")
    duedatestr: Optional[StrictStr] = Field(description="duedate for the user")
    fullname: Optional[StrictStr] = Field(description="The fullname of the user")
    grantedextension: Optional[StrictBool] = Field(description="have they been granted an extension")
    groupid: Optional[StrictInt] = Field(default=None, description="for group assignments this is the group id")
    groupname: Optional[StrictStr] = Field(default=None, description="for group assignments this is the group name")
    id: Optional[StrictInt] = Field(description="ID of the user")
    requiregrading: Optional[StrictBool] = Field(description="is their submission waiting for grading")
    submissionstatus: Optional[StrictStr] = Field(default=None, description="The submission status (new, draft, reopened or submitted).                 Empty when not submitted.")
    submitted: Optional[StrictBool] = Field(description="have they submitted their assignment")
    user: Optional[CoreEnrolGetPotentialUsersResponseInner] = None
    __properties: ClassVar[List[str]] = ["allowsubmissionsfromdate", "blindmarking", "cutoffdate", "duedate", "duedatestr", "fullname", "grantedextension", "groupid", "groupname", "id", "requiregrading", "submissionstatus", "submitted", "user"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModAssignGetParticipantResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # set to None if allowsubmissionsfromdate (nullable) is None
        # and model_fields_set contains the field
        if self.allowsubmissionsfromdate is None and "allowsubmissionsfromdate" in self.model_fields_set:
            _dict['allowsubmissionsfromdate'] = None

        # set to None if blindmarking (nullable) is None
        # and model_fields_set contains the field
        if self.blindmarking is None and "blindmarking" in self.model_fields_set:
            _dict['blindmarking'] = None

        # set to None if cutoffdate (nullable) is None
        # and model_fields_set contains the field
        if self.cutoffdate is None and "cutoffdate" in self.model_fields_set:
            _dict['cutoffdate'] = None

        # set to None if duedate (nullable) is None
        # and model_fields_set contains the field
        if self.duedate is None and "duedate" in self.model_fields_set:
            _dict['duedate'] = None

        # set to None if duedatestr (nullable) is None
        # and model_fields_set contains the field
        if self.duedatestr is None and "duedatestr" in self.model_fields_set:
            _dict['duedatestr'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if grantedextension (nullable) is None
        # and model_fields_set contains the field
        if self.grantedextension is None and "grantedextension" in self.model_fields_set:
            _dict['grantedextension'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if groupname (nullable) is None
        # and model_fields_set contains the field
        if self.groupname is None and "groupname" in self.model_fields_set:
            _dict['groupname'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if requiregrading (nullable) is None
        # and model_fields_set contains the field
        if self.requiregrading is None and "requiregrading" in self.model_fields_set:
            _dict['requiregrading'] = None

        # set to None if submissionstatus (nullable) is None
        # and model_fields_set contains the field
        if self.submissionstatus is None and "submissionstatus" in self.model_fields_set:
            _dict['submissionstatus'] = None

        # set to None if submitted (nullable) is None
        # and model_fields_set contains the field
        if self.submitted is None and "submitted" in self.model_fields_set:
            _dict['submitted'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModAssignGetParticipantResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModAssignGetParticipantResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "allowsubmissionsfromdate": obj.get("allowsubmissionsfromdate"),
            "blindmarking": obj.get("blindmarking"),
            "cutoffdate": obj.get("cutoffdate"),
            "duedate": obj.get("duedate"),
            "duedatestr": obj.get("duedatestr"),
            "fullname": obj.get("fullname"),
            "grantedextension": obj.get("grantedextension"),
            "groupid": obj.get("groupid"),
            "groupname": obj.get("groupname"),
            "id": obj.get("id"),
            "requiregrading": obj.get("requiregrading"),
            "submissionstatus": obj.get("submissionstatus"),
            "submitted": obj.get("submitted"),
            "user": CoreEnrolGetPotentialUsersResponseInner.from_dict(obj["user"]) if obj.get("user") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer(BaseModel):
    """
    The option user answer
    """ # noqa: E501
    answer: Optional[StrictStr] = Field(default=None, description="Option text value")
    checked: Optional[StrictBool] = Field(default=None, description="If has to be displayed as a checked option")
    correct: Optional[StrictBool] = Field(default=None, description="If has to be displayed as correct")
    fail: Optional[StrictBool] = Field(default=None, description="If has to be displayed as failed")
    incorrect: Optional[StrictBool] = Field(default=None, description="If has to be displayed as incorrect")
    var_pass: Optional[StrictBool] = Field(default=None, description="If has to be displayed as passed", alias="pass")
    text: Optional[StrictBool] = Field(default=None, description="If has to be displayed as simple text")
    unchecked: Optional[StrictBool] = Field(default=None, description="If has to be displayed as a unchecked option")
    __properties: ClassVar[List[str]] = ["answer", "checked", "correct", "fail", "incorrect", "pass", "text", "unchecked"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if answer (nullable) is None
        # and model_fields_set contains the field
        if self.answer is None and "answer" in self.model_fields_set:
            _dict['answer'] = None

        # set to None if checked (nullable) is None
        # and model_fields_set contains the field
        if self.checked is None and "checked" in self.model_fields_set:
            _dict['checked'] = None

        # set to None if correct (nullable) is None
        # and model_fields_set contains the field
        if self.correct is None and "correct" in self.model_fields_set:
            _dict['correct'] = None

        # set to None if fail (nullable) is None
        # and model_fields_set contains the field
        if self.fail is None and "fail" in self.model_fields_set:
            _dict['fail'] = None

        # set to None if incorrect (nullable) is None
        # and model_fields_set contains the field
        if self.incorrect is None and "incorrect" in self.model_fields_set:
            _dict['incorrect'] = None

        # set to None if var_pass (nullable) is None
        # and model_fields_set contains the field
        if self.var_pass is None and "var_pass" in self.model_fields_set:
            _dict['pass'] = None

        # set to None if text (nullable) is None
        # and model_fields_set contains the field
        if self.text is None and "text" in self.model_fields_set:
            _dict['text'] = None

        # set to None if unchecked (nullable) is None
        # and model_fields_set contains the field
        if self.unchecked is None and "unchecked" in self.model_fields_set:
            _dict['unchecked'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "answer": obj.get("answer"),
            "checked": obj.get("checked"),
            "correct": obj.get("correct"),
            "fail": obj.get("fail"),
            "incorrect": obj.get("incorrect"),
            "pass": obj.get("pass"),
            "text": obj.get("text"),
            "unchecked": obj.get("unchecked")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner(BaseModel):
    """
    Activity
    """ # noqa: E501
    cmid: Optional[StrictInt] = Field(description="course module ID")
    details: Optional[List[CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner]] = Field(default=None, description="Completion status details")
    hascompletion: Optional[StrictBool] = Field(default=None, description="Whether this activity module has completion enabled")
    instance: Optional[StrictInt] = Field(description="instance ID")
    isautomatic: Optional[StrictBool] = Field(default=None, description="Whether this activity module instance tracks completion automatically.")
    isoverallcomplete: Optional[StrictBool] = Field(default=None, description="Whether the overall completion state of this course module should be marked as complete or not.")
    istrackeduser: Optional[StrictBool] = Field(default=None, description="Whether completion is being tracked for this user.")
    modname: Optional[StrictStr] = Field(description="activity module name")
    overrideby: Optional[StrictInt] = Field(default=None, description="The user id who has overriden the status, or null")
    state: Optional[StrictInt] = Field(description="Completion state value:                                     0 means incomplete,                                     1 complete,                                     2 complete pass,                                     3 complete fail")
    timecompleted: Optional[StrictInt] = Field(description="timestamp for completed activity")
    tracking: Optional[StrictInt] = Field(description="type of tracking:                                     0 means none,                                     1 manual,                                     2 automatic")
    uservisible: Optional[StrictBool] = Field(default=None, description="Whether this activity is visible to the user.")
    valueused: Optional[StrictBool] = Field(default=None, description="Whether the completion status affects the availability of another activity.")
    __properties: ClassVar[List[str]] = ["cmid", "details", "hascompletion", "instance", "isautomatic", "isoverallcomplete", "istrackeduser", "modname", "overrideby", "state", "timecompleted", "tracking", "uservisible", "valueused"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in details (list)
        _items = []
        if self.details:
            for _item_details in self.details:
                if _item_details:
                    _items.append(_item_details.to_dict())
            _dict['details'] = _items
        # set to None if cmid (nullable) is None
        # and model_fields_set contains the field
        if self.cmid is None and "cmid" in self.model_fields_set:
            _dict['cmid'] = None

        # set to None if hascompletion (nullable) is None
        # and model_fields_set contains the field
        if self.hascompletion is None and "hascompletion" in self.model_fields_set:
            _dict['hascompletion'] = None

        # set to None if instance (nullable) is None
        # and model_fields_set contains the field
        if self.instance is None and "instance" in self.model_fields_set:
            _dict['instance'] = None

        # set to None if isautomatic (nullable) is None
        # and model_fields_set contains the field
        if self.isautomatic is None and "isautomatic" in self.model_fields_set:
            _dict['isautomatic'] = None

        # set to None if isoverallcomplete (nullable) is None
        # and model_fields_set contains the field
        if self.isoverallcomplete is None and "isoverallcomplete" in self.model_fields_set:
            _dict['isoverallcomplete'] = None

        # set to None if istrackeduser (nullable) is None
        # and model_fields_set contains the field
        if self.istrackeduser is None and "istrackeduser" in self.model_fields_set:
            _dict['istrackeduser'] = None

        # set to None if modname (nullable) is None
        # and model_fields_set contains the field
        if self.modname is None and "modname" in self.model_fields_set:
            _dict['modname'] = None

        # set to None if overrideby (nullable) is None
        # and model_fields_set contains the field
        if self.overrideby is None and "overrideby" in self.model_fields_set:
            _dict['overrideby'] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict['state'] = None

        # set to None if timecompleted (nullable) is None
        # and model_fields_set contains the field
        if self.timecompleted is None and "timecompleted" in self.model_fields_set:
            _dict['timecompleted'] = None

        # set to None if tracking (nullable) is None
        # and model_fields_set contains the field
        if self.tracking is None and "tracking" in self.model_fields_set:
            _dict['tracking'] = None

        # set to None if uservisible (nullable) is None
        # and model_fields_set contains the field
        if self.uservisible is None and "uservisible" in self.model_fields_set:
            _dict['uservisible'] = None

        # set to None if valueused (nullable) is None
        # and model_fields_set contains the field
        if self.valueused is None and "valueused" in self.model_fields_set:
            _dict['valueused'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "cmid": obj.get("cmid"),
            "details": [CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner.from_dict(_item) for _item in obj["details"]] if obj.get("details") is not None else None,
            "hascompletion": obj.get("hascompletion"),
            "instance": obj.get("instance"),
            "isautomatic": obj.get("isautomatic"),
            "isoverallcomplete": obj.get("isoverallcomplete"),
            "istrackeduser": obj.get("istrackeduser"),
            "modname": obj.get("modname"),
            "overrideby": obj.get("overrideby"),
            "state": obj.get("state"),
            "timecompleted": obj.get("timecompleted"),
            "tracking": obj.get("tracking"),
            "uservisible": obj.get("uservisible"),
            "valueused": obj.get("valueused")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.mod_lti_create_tool_type_response_state import ModLtiCreateToolTypeResponseState
from poodle_async_full.models.mod_lti_create_tool_type_response_urls import ModLtiCreateToolTypeResponseUrls
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModLtiUpdateToolTypeResponse(BaseModel):
    """
    Tool
    """ # noqa: E501
    capabilitygroups: Optional[List[Optional[StrictStr]]] = Field(default=None, description="Array of capability groups")
    clientid: Optional[StrictStr] = Field(description="Client ID")
    courseid: Optional[StrictInt] = Field(default=0, description="Tool type course")
    deploymentid: Optional[StrictInt] = Field(description="Deployment ID")
    description: Optional[StrictStr] = Field(description="Tool type description")
    hascapabilitygroups: Optional[StrictBool] = Field(description="Indicate if capabilitygroups is populated")
    id: Optional[StrictInt] = Field(description="Tool type id")
    instancecount: Optional[StrictInt] = Field(description="The number of times this tool is being used")
    instanceids: Optional[List[Optional[StrictInt]]] = Field(default=None, description="IDs for the LTI instances using this type")
    name: Optional[StrictStr] = Field(description="Tool type name")
    platformid: Optional[StrictStr] = Field(description="Platform ID")
    state: ModLtiCreateToolTypeResponseState
    urls: ModLtiCreateToolTypeResponseUrls
    __properties: ClassVar[List[str]] = ["capabilitygroups", "clientid", "courseid", "deploymentid", "description", "hascapabilitygroups", "id", "instancecount", "instanceids", "name", "platformid", "state", "urls"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModLtiUpdateToolTypeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of state
        if self.state:
            _dict['state'] = self.state.to_dict()
        # override the default output from pydantic by calling `to_dict()` of urls
        if self.urls:
            _dict['urls'] = self.urls.to_dict()
        # set to None if clientid (nullable) is None
        # and model_fields_set contains the field
        if self.clientid is None and "clientid" in self.model_fields_set:
            _dict['clientid'] = None

        # set to None if courseid (nullable) is None
        # and model_fields_set contains the field
        if self.courseid is None and "courseid" in self.model_fields_set:
            _dict['courseid'] = None

        # set to None if deploymentid (nullable) is None
        # and model_fields_set contains the field
        if self.deploymentid is None and "deploymentid" in self.model_fields_set:
            _dict['deploymentid'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if hascapabilitygroups (nullable) is None
        # and model_fields_set contains the field
        if self.hascapabilitygroups is None and "hascapabilitygroups" in self.model_fields_set:
            _dict['hascapabilitygroups'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if instancecount (nullable) is None
        # and model_fields_set contains the field
        if self.instancecount is None and "instancecount" in self.model_fields_set:
            _dict['instancecount'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if platformid (nullable) is None
        # and model_fields_set contains the field
        if self.platformid is None and "platformid" in self.model_fields_set:
            _dict['platformid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModLtiUpdateToolTypeResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModLtiUpdateToolTypeResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "capabilitygroups": obj.get("capabilitygroups"),
            "clientid": obj.get("clientid"),
            "courseid": obj.get("courseid") if obj.get("courseid") is not None else 0,
            "deploymentid": obj.get("deploymentid"),
            "description": obj.get("description"),
            "hascapabilitygroups": obj.get("hascapabilitygroups"),
            "id": obj.get("id"),
            "instancecount": obj.get("instancecount"),
            "instanceids": obj.get("instanceids"),
            "name": obj.get("name"),
            "platformid": obj.get("platformid"),
            "state": ModLtiCreateToolTypeResponseState.from_dict(obj["state"]) if obj.get("state") is not None else None,
            "urls": ModLtiCreateToolTypeResponseUrls.from_dict(obj["urls"]) if obj.get("urls") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreEnrolGetUsersCoursesResponseInner(BaseModel):
    """
    CoreEnrolGetUsersCoursesResponseInner
    """ # noqa: E501
    category: Optional[StrictInt] = Field(default=None, description="course category id")
    completed: Optional[StrictBool] = Field(default=None, description="Whether the course is completed.")
    completionhascriteria: Optional[StrictBool] = Field(default=None, description="If completion criteria is set.")
    completionusertracked: Optional[StrictBool] = Field(default=None, description="If the user is completion tracked.")
    courseimage: Optional[StrictStr] = Field(default=None, description="The course image URL")
    displayname: Optional[StrictStr] = Field(default=None, description="course display name for lists.")
    enablecompletion: Optional[StrictBool] = Field(default=None, description="true if completion is enabled, otherwise false")
    enddate: Optional[StrictInt] = Field(default=None, description="Timestamp when the course end")
    enrolledusercount: Optional[StrictInt] = Field(default=None, description="Number of enrolled users in this course")
    format: Optional[StrictStr] = Field(default=None, description="course format: weeks, topics, social, site")
    fullname: Optional[StrictStr] = Field(description="long name of course")
    hidden: Optional[StrictBool] = Field(default=None, description="If the user hide the course from the dashboard.")
    id: Optional[StrictInt] = Field(description="id of course")
    idnumber: Optional[StrictStr] = Field(description="id number of course")
    isfavourite: Optional[StrictBool] = Field(default=None, description="If the user marked this course a favourite.")
    lang: Optional[StrictStr] = Field(default=None, description="forced course language")
    lastaccess: Optional[StrictInt] = Field(default=None, description="Last access to the course (timestamp).")
    marker: Optional[StrictInt] = Field(default=None, description="Course section marker.")
    overviewfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Overview files attached to this course.")
    progress: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Progress percentage")
    shortname: Optional[StrictStr] = Field(description="short name of course")
    showactivitydates: Optional[StrictBool] = Field(description="Whether the activity dates are shown or not")
    showcompletionconditions: Optional[StrictBool] = Field(description="Whether the activity completion conditions are shown or not")
    showgrades: Optional[StrictBool] = Field(default=None, description="true if grades are shown, otherwise false")
    startdate: Optional[StrictInt] = Field(default=None, description="Timestamp when the course start")
    summary: Optional[StrictStr] = Field(default=None, description="summary")
    summaryformat: Optional[StrictInt] = Field(default=None, description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    timemodified: Optional[StrictInt] = Field(default=None, description="Last time course settings were updated (timestamp).")
    visible: Optional[StrictInt] = Field(description="1 means visible, 0 means not yet visible course")
    __properties: ClassVar[List[str]] = ["category", "completed", "completionhascriteria", "completionusertracked", "courseimage", "displayname", "enablecompletion", "enddate", "enrolledusercount", "format", "fullname", "hidden", "id", "idnumber", "isfavourite", "lang", "lastaccess", "marker", "overviewfiles", "progress", "shortname", "showactivitydates", "showcompletionconditions", "showgrades", "startdate", "summary", "summaryformat", "timemodified", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreEnrolGetUsersCoursesResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in overviewfiles (list)
        _items = []
        if self.overviewfiles:
            for _item_overviewfiles in self.overviewfiles:
                if _item_overviewfiles:
                    _items.append(_item_overviewfiles.to_dict())
            _dict['overviewfiles'] = _items
        # set to None if category (nullable) is None
        # and model_fields_set contains the field
        if self.category is None and "category" in self.model_fields_set:
            _dict['category'] = None

        # set to None if completed (nullable) is None
        # and model_fields_set contains the field
        if self.completed is None and "completed" in self.model_fields_set:
            _dict['completed'] = None

        # set to None if completionhascriteria (nullable) is None
        # and model_fields_set contains the field
        if self.completionhascriteria is None and "completionhascriteria" in self.model_fields_set:
            _dict['completionhascriteria'] = None

        # set to None if completionusertracked (nullable) is None
        # and model_fields_set contains the field
        if self.completionusertracked is None and "completionusertracked" in self.model_fields_set:
            _dict['completionusertracked'] = None

        # set to None if courseimage (nullable) is None
        # and model_fields_set contains the field
        if self.courseimage is None and "courseimage" in self.model_fields_set:
            _dict['courseimage'] = None

        # set to None if displayname (nullable) is None
        # and model_fields_set contains the field
        if self.displayname is None and "displayname" in self.model_fields_set:
            _dict['displayname'] = None

        # set to None if enablecompletion (nullable) is None
        # and model_fields_set contains the field
        if self.enablecompletion is None and "enablecompletion" in self.model_fields_set:
            _dict['enablecompletion'] = None

        # set to None if enddate (nullable) is None
        # and model_fields_set contains the field
        if self.enddate is None and "enddate" in self.model_fields_set:
            _dict['enddate'] = None

        # set to None if enrolledusercount (nullable) is None
        # and model_fields_set contains the field
        if self.enrolledusercount is None and "enrolledusercount" in self.model_fields_set:
            _dict['enrolledusercount'] = None

        # set to None if format (nullable) is None
        # and model_fields_set contains the field
        if self.format is None and "format" in self.model_fields_set:
            _dict['format'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if hidden (nullable) is None
        # and model_fields_set contains the field
        if self.hidden is None and "hidden" in self.model_fields_set:
            _dict['hidden'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if isfavourite (nullable) is None
        # and model_fields_set contains the field
        if self.isfavourite is None and "isfavourite" in self.model_fields_set:
            _dict['isfavourite'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if lastaccess (nullable) is None
        # and model_fields_set contains the field
        if self.lastaccess is None and "lastaccess" in self.model_fields_set:
            _dict['lastaccess'] = None

        # set to None if marker (nullable) is None
        # and model_fields_set contains the field
        if self.marker is None and "marker" in self.model_fields_set:
            _dict['marker'] = None

        # set to None if progress (nullable) is None
        # and model_fields_set contains the field
        if self.progress is None and "progress" in self.model_fields_set:
            _dict['progress'] = None

        # set to None if shortname (nullable) is None
        # and model_fields_set contains the field
        if self.shortname is None and "shortname" in self.model_fields_set:
            _dict['shortname'] = None

        # set to None if showactivitydates (nullable) is None
        # and model_fields_set contains the field
        if self.showactivitydates is None and "showactivitydates" in self.model_fields_set:
            _dict['showactivitydates'] = None

        # set to None if showcompletionconditions (nullable) is None
        # and model_fields_set contains the field
        if self.showcompletionconditions is None and "showcompletionconditions" in self.model_fields_set:
            _dict['showcompletionconditions'] = None

        # set to None if showgrades (nullable) is None
        # and model_fields_set contains the field
        if self.showgrades is None and "showgrades" in self.model_fields_set:
            _dict['showgrades'] = None

        # set to None if startdate (nullable) is None
        # and model_fields_set contains the field
        if self.startdate is None and "startdate" in self.model_fields_set:
            _dict['startdate'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreEnrolGetUsersCoursesResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreEnrolGetUsersCoursesResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "category": obj.get("category"),
            "completed": obj.get("completed"),
            "completionhascriteria": obj.get("completionhascriteria"),
            "completionusertracked": obj.get("completionusertracked"),
            "courseimage": obj.get("courseimage"),
            "displayname": obj.get("displayname"),
            "enablecompletion": obj.get("enablecompletion"),
            "enddate": obj.get("enddate"),
            "enrolledusercount": obj.get("enrolledusercount"),
            "format": obj.get("format"),
            "fullname": obj.get("fullname"),
            "hidden": obj.get("hidden"),
            "id": obj.get("id"),
            "idnumber": obj.get("idnumber"),
            "isfavourite": obj.get("isfavourite"),
            "lang": obj.get("lang"),
            "lastaccess": obj.get("lastaccess"),
            "marker": obj.get("marker"),
            "overviewfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["overviewfiles"]] if obj.get("overviewfiles") is not None else None,
            "progress": obj.get("progress"),
            "shortname": obj.get("shortname"),
            "showactivitydates": obj.get("showactivitydates"),
            "showcompletionconditions": obj.get("showcompletionconditions"),
            "showgrades": obj.get("showgrades"),
            "startdate": obj.get("startdate"),
            "summary": obj.get("summary"),
            "summaryformat": obj.get("summaryformat"),
            "timemodified": obj.get("timemodified"),
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModLessonGetPageDataResponsePage(BaseModel):
    """
    Page fields
    """ # noqa: E501
    contents: Optional[StrictStr] = Field(default=None, description="The contents of this page")
    contentsformat: Optional[StrictInt] = Field(default=None, description="contents format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    display: Optional[StrictInt] = Field(description="Used to record page specific display selections")
    displayinmenublock: Optional[StrictBool] = Field(description="Toggles display in the left menu block")
    id: Optional[StrictInt] = Field(description="The id of this lesson page")
    layout: Optional[StrictInt] = Field(description="Used to record page specific layout selections")
    lessonid: Optional[StrictInt] = Field(description="The id of the lesson this page belongs to")
    nextpageid: Optional[StrictInt] = Field(description="The id of the next page in the page sequence")
    prevpageid: Optional[StrictInt] = Field(description="The id of the page before this one")
    qoption: Optional[StrictInt] = Field(description="Used to record page type specific options")
    qtype: Optional[StrictInt] = Field(description="Identifies the page type of this page")
    timecreated: Optional[StrictInt] = Field(description="Timestamp for when the page was created")
    timemodified: Optional[StrictInt] = Field(description="Timestamp for when the page was last modified")
    title: Optional[StrictStr] = Field(default=None, description="The title of this page")
    type: Optional[StrictInt] = Field(description="The type of the page [question | structure]")
    typeid: Optional[StrictInt] = Field(description="The unique identifier for the page type")
    typestring: Optional[StrictStr] = Field(description="The string that describes this page type")
    __properties: ClassVar[List[str]] = ["contents", "contentsformat", "display", "displayinmenublock", "id", "layout", "lessonid", "nextpageid", "prevpageid", "qoption", "qtype", "timecreated", "timemodified", "title", "type", "typeid", "typestring"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModLessonGetPageDataResponsePage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if contents (nullable) is None
        # and model_fields_set contains the field
        if self.contents is None and "contents" in self.model_fields_set:
            _dict['contents'] = None

        # set to None if contentsformat (nullable) is None
        # and model_fields_set contains the field
        if self.contentsformat is None and "contentsformat" in self.model_fields_set:
            _dict['contentsformat'] = None

        # set to None if display (nullable) is None
        # and model_fields_set contains the field
        if self.display is None and "display" in self.model_fields_set:
            _dict['display'] = None

        # set to None if displayinmenublock (nullable) is None
        # and model_fields_set contains the field
        if self.displayinmenublock is None and "displayinmenublock" in self.model_fields_set:
            _dict['displayinmenublock'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if layout (nullable) is None
        # and model_fields_set contains the field
        if self.layout is None and "layout" in self.model_fields_set:
            _dict['layout'] = None

        # set to None if lessonid (nullable) is None
        # and model_fields_set contains the field
        if self.lessonid is None and "lessonid" in self.model_fields_set:
            _dict['lessonid'] = None

        # set to None if nextpageid (nullable) is None
        # and model_fields_set contains the field
        if self.nextpageid is None and "nextpageid" in self.model_fields_set:
            _dict['nextpageid'] = None

        # set to None if prevpageid (nullable) is None
        # and model_fields_set contains the field
        if self.prevpageid is None and "prevpageid" in self.model_fields_set:
            _dict['prevpageid'] = None

        # set to None if qoption (nullable) is None
        # and model_fields_set contains the field
        if self.qoption is None and "qoption" in self.model_fields_set:
            _dict['qoption'] = None

        # set to None if qtype (nullable) is None
        # and model_fields_set contains the field
        if self.qtype is None and "qtype" in self.model_fields_set:
            _dict['qtype'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if typeid (nullable) is None
        # and model_fields_set contains the field
        if self.typeid is None and "typeid" in self.model_fields_set:
            _dict['typeid'] = None

        # set to None if typestring (nullable) is None
        # and model_fields_set contains the field
        if self.typestring is None and "typestring" in self.model_fields_set:
            _dict['typestring'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModLessonGetPageDataResponsePage from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModLessonGetPageDataResponsePage" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "contents": obj.get("contents"),
            "contentsformat": obj.get("contentsformat"),
            "display": obj.get("display"),
            "displayinmenublock": obj.get("displayinmenublock"),
            "id": obj.get("id"),
            "layout": obj.get("layout"),
            "lessonid": obj.get("lessonid"),
            "nextpageid": obj.get("nextpageid"),
            "prevpageid": obj.get("prevpageid"),
            "qoption": obj.get("qoption"),
            "qtype": obj.get("qtype"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "title": obj.get("title"),
            "type": obj.get("type"),
            "typeid": obj.get("typeid"),
            "typestring": obj.get("typestring")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModFolderGetFoldersByCoursesResponseFoldersInner(BaseModel):
    """
    ModFolderGetFoldersByCoursesResponseFoldersInner
    """ # noqa: E501
    course: Optional[StrictInt] = Field(description="Course id")
    coursemodule: Optional[StrictInt] = Field(description="Course module id")
    display: Optional[StrictInt] = Field(description="Display type of folder contents on a separate page or inline")
    forcedownload: Optional[StrictInt] = Field(description="Whether file download is forced")
    groupingid: Optional[StrictInt] = Field(default=None, description="Group id")
    groupmode: Optional[StrictInt] = Field(default=None, description="Group mode")
    id: Optional[StrictInt] = Field(description="Activity instance id")
    intro: Optional[StrictStr] = Field(description="Activity introduction")
    introfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files in the introduction")
    introformat: Optional[StrictInt] = Field(description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(default=None, description="Forced activity language")
    name: Optional[StrictStr] = Field(description="Activity name")
    revision: Optional[StrictInt] = Field(description="Incremented when after each file changes, to avoid cache")
    section: Optional[StrictInt] = Field(default=None, description="Course section id")
    showdownloadfolder: Optional[StrictInt] = Field(description="Whether to show the download folder button")
    showexpanded: Optional[StrictInt] = Field(description="1 = expanded, 0 = collapsed for sub-folders")
    timemodified: Optional[StrictInt] = Field(description="Last time the folder was modified")
    visible: Optional[StrictBool] = Field(default=None, description="Visible")
    __properties: ClassVar[List[str]] = ["course", "coursemodule", "display", "forcedownload", "groupingid", "groupmode", "id", "intro", "introfiles", "introformat", "lang", "name", "revision", "section", "showdownloadfolder", "showexpanded", "timemodified", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModFolderGetFoldersByCoursesResponseFoldersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if coursemodule (nullable) is None
        # and model_fields_set contains the field
        if self.coursemodule is None and "coursemodule" in self.model_fields_set:
            _dict['coursemodule'] = None

        # set to None if display (nullable) is None
        # and model_fields_set contains the field
        if self.display is None and "display" in self.model_fields_set:
            _dict['display'] = None

        # set to None if forcedownload (nullable) is None
        # and model_fields_set contains the field
        if self.forcedownload is None and "forcedownload" in self.model_fields_set:
            _dict['forcedownload'] = None

        # set to None if groupingid (nullable) is None
        # and model_fields_set contains the field
        if self.groupingid is None and "groupingid" in self.model_fields_set:
            _dict['groupingid'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if revision (nullable) is None
        # and model_fields_set contains the field
        if self.revision is None and "revision" in self.model_fields_set:
            _dict['revision'] = None

        # set to None if section (nullable) is None
        # and model_fields_set contains the field
        if self.section is None and "section" in self.model_fields_set:
            _dict['section'] = None

        # set to None if showdownloadfolder (nullable) is None
        # and model_fields_set contains the field
        if self.showdownloadfolder is None and "showdownloadfolder" in self.model_fields_set:
            _dict['showdownloadfolder'] = None

        # set to None if showexpanded (nullable) is None
        # and model_fields_set contains the field
        if self.showexpanded is None and "showexpanded" in self.model_fields_set:
            _dict['showexpanded'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModFolderGetFoldersByCoursesResponseFoldersInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModFolderGetFoldersByCoursesResponseFoldersInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "course": obj.get("course"),
            "coursemodule": obj.get("coursemodule"),
            "display": obj.get("display"),
            "forcedownload": obj.get("forcedownload"),
            "groupingid": obj.get("groupingid"),
            "groupmode": obj.get("groupmode"),
            "id": obj.get("id"),
            "intro": obj.get("intro"),
            "introfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat"),
            "lang": obj.get("lang"),
            "name": obj.get("name"),
            "revision": obj.get("revision"),
            "section": obj.get("section"),
            "showdownloadfolder": obj.get("showdownloadfolder"),
            "showexpanded": obj.get("showexpanded"),
            "timemodified": obj.get("timemodified"),
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModQuizGetQuizzesByCoursesResponseQuizzesInner(BaseModel):
    """
    ModQuizGetQuizzesByCoursesResponseQuizzesInner
    """ # noqa: E501
    allowofflineattempts: Optional[StrictInt] = Field(default=None, description="Whether to allow the quiz to be attempted                                                                             offline in the mobile app")
    attemptonlast: Optional[StrictInt] = Field(default=None, description="Whether subsequent attempts start from the answer                                                                     to the previous attempt (1) or start blank (0).")
    attempts: Optional[StrictInt] = Field(default=None, description="The maximum number of attempts a student is allowed.")
    autosaveperiod: Optional[StrictInt] = Field(default=None, description="Auto-save delay")
    browsersecurity: Optional[StrictStr] = Field(default=None, description="Restriciton on the browser the student must                                                                     use. E.g. 'securewindow'.")
    canredoquestions: Optional[StrictInt] = Field(default=None, description="Allows students to redo any completed question                                                                         within a quiz attempt.")
    completionattemptsexhausted: Optional[StrictInt] = Field(default=None, description="Mark quiz complete when the student has                                                                                 exhausted the maximum number of attempts")
    completionpass: Optional[StrictInt] = Field(default=None, description="Whether to require passing grade")
    course: Optional[StrictInt] = Field(description="Course id")
    coursemodule: Optional[StrictInt] = Field(description="Course module id")
    decimalpoints: Optional[StrictInt] = Field(default=None, description="Number of decimal points to use when displaying                                                                     grades.")
    delay1: Optional[StrictInt] = Field(default=None, description="Delay that must be left between the first and second attempt,                                                             in seconds.")
    delay2: Optional[StrictInt] = Field(default=None, description="Delay that must be left between the second and subsequent                                                             attempt, in seconds.")
    graceperiod: Optional[StrictInt] = Field(default=None, description="The amount of time (in seconds) after the time limit                                                                 runs out during which attempts can still be submitted,                                                                 if overduehandling is set to allow it.")
    grade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The total that the quiz overall grade is scaled to be                                                             out of.")
    grademethod: Optional[StrictInt] = Field(default=None, description="One of the values QUIZ_GRADEHIGHEST, QUIZ_GRADEAVERAGE,                                                                     QUIZ_ATTEMPTFIRST or QUIZ_ATTEMPTLAST.")
    groupingid: Optional[StrictInt] = Field(default=None, description="Group id")
    groupmode: Optional[StrictInt] = Field(default=None, description="Group mode")
    hasfeedback: Optional[StrictInt] = Field(default=None, description="Whether the quiz has any non-blank feedback text")
    hasquestions: Optional[StrictInt] = Field(default=None, description="Whether the quiz has questions")
    id: Optional[StrictInt] = Field(description="Activity instance id")
    intro: Optional[StrictStr] = Field(default=None, description="Activity introduction")
    introfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files in the introduction")
    introformat: Optional[StrictInt] = Field(default=None, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(default=None, description="Forced activity language")
    name: Optional[StrictStr] = Field(description="Activity name")
    navmethod: Optional[StrictStr] = Field(default=None, description="Any constraints on how the user is allowed to navigate                                                                 around the quiz. Currently recognised values are                                                                 'free' and 'seq'.")
    overduehandling: Optional[StrictStr] = Field(default=None, description="The method used to handle overdue attempts.                                                                     'autosubmit', 'graceperiod' or 'autoabandon'.")
    password: Optional[StrictStr] = Field(default=None, description="A password that the student must enter before starting or                                                                 continuing a quiz attempt.")
    precreateattempts: Optional[StrictInt] = Field(default=None, description="Whether attempt pre-creation is enabled")
    preferredbehaviour: Optional[StrictStr] = Field(default=None, description="The behaviour to ask questions to use.")
    questiondecimalpoints: Optional[StrictInt] = Field(default=None, description="Number of decimal points to use when                                                                             displaying question grades.                                                                             (-1 means use decimalpoints.)")
    questionsperpage: Optional[StrictInt] = Field(default=None, description="How often to insert a page break when editing                                                                         the quiz, or when shuffling the question order.")
    reviewattempt: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their quiz                                                                     attempts at various times. This is a bit field, decoded by the                                                                     \\mod_quiz\\question\\display_options class. It is formed by ORing                                                                     together the constants defined there.")
    reviewcorrectness: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their quiz                                                        attempts at various times.A bit field, like reviewattempt.")
    reviewgeneralfeedback: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their                                                                             quiz attempts at various times. A bit field, like                                                                             reviewattempt.")
    reviewmarks: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their quiz attempts                                                                 at various times. A bit field, like reviewattempt.")
    reviewmaxmarks: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their quiz                                                   attempts at various times. A bit field, like reviewattempt.")
    reviewoverallfeedback: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their quiz                                                                             attempts at various times. A bit field, like                                                                             reviewattempt.")
    reviewrightanswer: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their quiz                                                                         attempts at various times. A bit field, like                                                                         reviewattempt.")
    reviewspecificfeedback: Optional[StrictInt] = Field(default=None, description="Whether users are allowed to review their                                                                             quiz attempts at various times. A bit field, like                                                                             reviewattempt.")
    section: Optional[StrictInt] = Field(default=None, description="Course section id")
    showblocks: Optional[StrictInt] = Field(default=None, description="Whether blocks should be shown on the attempt.php and                                                                 review.php pages.")
    showuserpicture: Optional[StrictInt] = Field(default=None, description="Option to show the user's picture during the                                                                     attempt and on the review page.")
    shuffleanswers: Optional[StrictInt] = Field(default=None, description="Whether the parts of the question should be shuffled,                                                                     in those question types that support it.")
    subnet: Optional[StrictStr] = Field(default=None, description="Used to restrict the IP addresses from which this quiz can                                                             be attempted. The format is as requried by the address_in_subnet                                                             function.")
    sumgrades: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The total of all the question instance maxmarks.")
    timeclose: Optional[StrictInt] = Field(default=None, description="The time when this quiz closes. (0 = no restriction.)")
    timecreated: Optional[StrictInt] = Field(default=None, description="The time when the quiz was added to the course.")
    timelimit: Optional[StrictInt] = Field(default=None, description="The time limit for quiz attempts, in seconds.")
    timemodified: Optional[StrictInt] = Field(default=None, description="Last modified time.")
    timeopen: Optional[StrictInt] = Field(default=None, description="The time when this quiz opens. (0 = no restriction.)")
    visible: Optional[StrictBool] = Field(default=None, description="Visible")
    __properties: ClassVar[List[str]] = ["allowofflineattempts", "attemptonlast", "attempts", "autosaveperiod", "browsersecurity", "canredoquestions", "completionattemptsexhausted", "completionpass", "course", "coursemodule", "decimalpoints", "delay1", "delay2", "graceperiod", "grade", "grademethod", "groupingid", "groupmode", "hasfeedback", "hasquestions", "id", "intro", "introfiles", "introformat", "lang", "name", "navmethod", "overduehandling", "password", "precreateattempts", "preferredbehaviour", "questiondecimalpoints", "questionsperpage", "reviewattempt", "reviewcorrectness", "reviewgeneralfeedback", "reviewmarks", "reviewmaxmarks", "reviewoverallfeedback", "reviewrightanswer", "reviewspecificfeedback", "section", "showblocks", "showuserpicture", "shuffleanswers", "subnet", "sumgrades", "timeclose", "timecreated", "timelimit", "timemodified", "timeopen", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModQuizGetQuizzesByCoursesResponseQuizzesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if allowofflineattempts (nullable) is None
        # and model_fields_set contains the field
        if self.allowofflineattempts is None and "allowofflineattempts" in self.model_fields_set:
            _dict['allowofflineattempts'] = None

        # set to None if attemptonlast (nullable) is None
        # and model_fields_set contains the field
        if self.attemptonlast is None and "attemptonlast" in self.model_fields_set:
            _dict['attemptonlast'] = None

        # set to None if attempts (nullable) is None
        # and model_fields_set contains the field
        if self.attempts is None and "attempts" in self.model_fields_set:
            _dict['attempts'] = None

        # set to None if autosaveperiod (nullable) is None
        # and model_fields_set contains the field
        if self.autosaveperiod is None and "autosaveperiod" in self.model_fields_set:
            _dict['autosaveperiod'] = None

        # set to None if browsersecurity (nullable) is None
        # and model_fields_set contains the field
        if self.browsersecurity is None and "browsersecurity" in self.model_fields_set:
            _dict['browsersecurity'] = None

        # set to None if canredoquestions (nullable) is None
        # and model_fields_set contains the field
        if self.canredoquestions is None and "canredoquestions" in self.model_fields_set:
            _dict['canredoquestions'] = None

        # set to None if completionattemptsexhausted (nullable) is None
        # and model_fields_set contains the field
        if self.completionattemptsexhausted is None and "completionattemptsexhausted" in self.model_fields_set:
            _dict['completionattemptsexhausted'] = None

        # set to None if completionpass (nullable) is None
        # and model_fields_set contains the field
        if self.completionpass is None and "completionpass" in self.model_fields_set:
            _dict['completionpass'] = None

        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if coursemodule (nullable) is None
        # and model_fields_set contains the field
        if self.coursemodule is None and "coursemodule" in self.model_fields_set:
            _dict['coursemodule'] = None

        # set to None if decimalpoints (nullable) is None
        # and model_fields_set contains the field
        if self.decimalpoints is None and "decimalpoints" in self.model_fields_set:
            _dict['decimalpoints'] = None

        # set to None if delay1 (nullable) is None
        # and model_fields_set contains the field
        if self.delay1 is None and "delay1" in self.model_fields_set:
            _dict['delay1'] = None

        # set to None if delay2 (nullable) is None
        # and model_fields_set contains the field
        if self.delay2 is None and "delay2" in self.model_fields_set:
            _dict['delay2'] = None

        # set to None if graceperiod (nullable) is None
        # and model_fields_set contains the field
        if self.graceperiod is None and "graceperiod" in self.model_fields_set:
            _dict['graceperiod'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if grademethod (nullable) is None
        # and model_fields_set contains the field
        if self.grademethod is None and "grademethod" in self.model_fields_set:
            _dict['grademethod'] = None

        # set to None if groupingid (nullable) is None
        # and model_fields_set contains the field
        if self.groupingid is None and "groupingid" in self.model_fields_set:
            _dict['groupingid'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if hasfeedback (nullable) is None
        # and model_fields_set contains the field
        if self.hasfeedback is None and "hasfeedback" in self.model_fields_set:
            _dict['hasfeedback'] = None

        # set to None if hasquestions (nullable) is None
        # and model_fields_set contains the field
        if self.hasquestions is None and "hasquestions" in self.model_fields_set:
            _dict['hasquestions'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if navmethod (nullable) is None
        # and model_fields_set contains the field
        if self.navmethod is None and "navmethod" in self.model_fields_set:
            _dict['navmethod'] = None

        # set to None if overduehandling (nullable) is None
        # and model_fields_set contains the field
        if self.overduehandling is None and "overduehandling" in self.model_fields_set:
            _dict['overduehandling'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if precreateattempts (nullable) is None
        # and model_fields_set contains the field
        if self.precreateattempts is None and "precreateattempts" in self.model_fields_set:
            _dict['precreateattempts'] = None

        # set to None if preferredbehaviour (nullable) is None
        # and model_fields_set contains the field
        if self.preferredbehaviour is None and "preferredbehaviour" in self.model_fields_set:
            _dict['preferredbehaviour'] = None

        # set to None if questiondecimalpoints (nullable) is None
        # and model_fields_set contains the field
        if self.questiondecimalpoints is None and "questiondecimalpoints" in self.model_fields_set:
            _dict['questiondecimalpoints'] = None

        # set to None if questionsperpage (nullable) is None
        # and model_fields_set contains the field
        if self.questionsperpage is None and "questionsperpage" in self.model_fields_set:
            _dict['questionsperpage'] = None

        # set to None if reviewattempt (nullable) is None
        # and model_fields_set contains the field
        if self.reviewattempt is None and "reviewattempt" in self.model_fields_set:
            _dict['reviewattempt'] = None

        # set to None if reviewcorrectness (nullable) is None
        # and model_fields_set contains the field
        if self.reviewcorrectness is None and "reviewcorrectness" in self.model_fields_set:
            _dict['reviewcorrectness'] = None

        # set to None if reviewgeneralfeedback (nullable) is None
        # and model_fields_set contains the field
        if self.reviewgeneralfeedback is None and "reviewgeneralfeedback" in self.model_fields_set:
            _dict['reviewgeneralfeedback'] = None

        # set to None if reviewmarks (nullable) is None
        # and model_fields_set contains the field
        if self.reviewmarks is None and "reviewmarks" in self.model_fields_set:
            _dict['reviewmarks'] = None

        # set to None if reviewmaxmarks (nullable) is None
        # and model_fields_set contains the field
        if self.reviewmaxmarks is None and "reviewmaxmarks" in self.model_fields_set:
            _dict['reviewmaxmarks'] = None

        # set to None if reviewoverallfeedback (nullable) is None
        # and model_fields_set contains the field
        if self.reviewoverallfeedback is None and "reviewoverallfeedback" in self.model_fields_set:
            _dict['reviewoverallfeedback'] = None

        # set to None if reviewrightanswer (nullable) is None
        # and model_fields_set contains the field
        if self.reviewrightanswer is None and "reviewrightanswer" in self.model_fields_set:
            _dict['reviewrightanswer'] = None

        # set to None if reviewspecificfeedback (nullable) is None
        # and model_fields_set contains the field
        if self.reviewspecificfeedback is None and "reviewspecificfeedback" in self.model_fields_set:
            _dict['reviewspecificfeedback'] = None

        # set to None if section (nullable) is None
        # and model_fields_set contains the field
        if self.section is None and "section" in self.model_fields_set:
            _dict['section'] = None

        # set to None if showblocks (nullable) is None
        # and model_fields_set contains the field
        if self.showblocks is None and "showblocks" in self.model_fields_set:
            _dict['showblocks'] = None

        # set to None if showuserpicture (nullable) is None
        # and model_fields_set contains the field
        if self.showuserpicture is None and "showuserpicture" in self.model_fields_set:
            _dict['showuserpicture'] = None

        # set to None if shuffleanswers (nullable) is None
        # and model_fields_set contains the field
        if self.shuffleanswers is None and "shuffleanswers" in self.model_fields_set:
            _dict['shuffleanswers'] = None

        # set to None if subnet (nullable) is None
        # and model_fields_set contains the field
        if self.subnet is None and "subnet" in self.model_fields_set:
            _dict['subnet'] = None

        # set to None if sumgrades (nullable) is None
        # and model_fields_set contains the field
        if self.sumgrades is None and "sumgrades" in self.model_fields_set:
            _dict['sumgrades'] = None

        # set to None if timeclose (nullable) is None
        # and model_fields_set contains the field
        if self.timeclose is None and "timeclose" in self.model_fields_set:
            _dict['timeclose'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timelimit (nullable) is None
        # and model_fields_set contains the field
        if self.timelimit is None and "timelimit" in self.model_fields_set:
            _dict['timelimit'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if timeopen (nullable) is None
        # and model_fields_set contains the field
        if self.timeopen is None and "timeopen" in self.model_fields_set:
            _dict['timeopen'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModQuizGetQuizzesByCoursesResponseQuizzesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModQuizGetQuizzesByCoursesResponseQuizzesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "allowofflineattempts": obj.get("allowofflineattempts"),
            "attemptonlast": obj.get("attemptonlast"),
            "attempts": obj.get("attempts"),
            "autosaveperiod": obj.get("autosaveperiod"),
            "browsersecurity": obj.get("browsersecurity"),
            "canredoquestions": obj.get("canredoquestions"),
            "completionattemptsexhausted": obj.get("completionattemptsexhausted"),
            "completionpass": obj.get("completionpass"),
            "course": obj.get("course"),
            "coursemodule": obj.get("coursemodule"),
            "decimalpoints": obj.get("decimalpoints"),
            "delay1": obj.get("delay1"),
            "delay2": obj.get("delay2"),
            "graceperiod": obj.get("graceperiod"),
            "grade": obj.get("grade"),
            "grademethod": obj.get("grademethod"),
            "groupingid": obj.get("groupingid"),
            "groupmode": obj.get("groupmode"),
            "hasfeedback": obj.get("hasfeedback"),
            "hasquestions": obj.get("hasquestions"),
            "id": obj.get("id"),
            "intro": obj.get("intro"),
            "introfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat"),
            "lang": obj.get("lang"),
            "name": obj.get("name"),
            "navmethod": obj.get("navmethod"),
            "overduehandling": obj.get("overduehandling"),
            "password": obj.get("password"),
            "precreateattempts": obj.get("precreateattempts"),
            "preferredbehaviour": obj.get("preferredbehaviour"),
            "questiondecimalpoints": obj.get("questiondecimalpoints"),
            "questionsperpage": obj.get("questionsperpage"),
            "reviewattempt": obj.get("reviewattempt"),
            "reviewcorrectness": obj.get("reviewcorrectness"),
            "reviewgeneralfeedback": obj.get("reviewgeneralfeedback"),
            "reviewmarks": obj.get("reviewmarks"),
            "reviewmaxmarks": obj.get("reviewmaxmarks"),
            "reviewoverallfeedback": obj.get("reviewoverallfeedback"),
            "reviewrightanswer": obj.get("reviewrightanswer"),
            "reviewspecificfeedback": obj.get("reviewspecificfeedback"),
            "section": obj.get("section"),
            "showblocks": obj.get("showblocks"),
            "showuserpicture": obj.get("showuserpicture"),
            "shuffleanswers": obj.get("shuffleanswers"),
            "subnet": obj.get("subnet"),
            "sumgrades": obj.get("sumgrades"),
            "timeclose": obj.get("timeclose"),
            "timecreated": obj.get("timecreated"),
            "timelimit": obj.get("timelimit"),
            "timemodified": obj.get("timemodified"),
            "timeopen": obj.get("timeopen"),
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_badges_get_badge_response_badge_alignment_inner import CoreBadgesGetBadgeResponseBadgeAlignmentInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreBadgesGetBadgeResponseBadge(BaseModel):
    """
    CoreBadgesGetBadgeResponseBadge
    """ # noqa: E501
    alignment: Optional[List[CoreBadgesGetBadgeResponseBadgeAlignmentInner]] = Field(default=None, description="alignment")
    coursefullname: Optional[StrictStr] = Field(default='', description="Full name of the course")
    courseid: Optional[StrictInt] = Field(default=0, description="Id of the course")
    criteria_narrative: Optional[StrictStr] = Field(default='', description="criteriaNarrative", alias="criteriaNarrative")
    criteria_url: Optional[StrictStr] = Field(default='', description="criteriaUrl", alias="criteriaUrl")
    description: StrictStr = Field(description="Description of the badge class.")
    hosted_url: Optional[StrictStr] = Field(default='', description="Identifier of the open badge for this assertion", alias="hostedUrl")
    id: StrictStr = Field(description="Unique identifier for this badgeclass")
    image: StrictStr = Field(description="URL to the image.")
    issuer: Optional[StrictStr] = Field(default='', description="Unique identifier for this badgeclass")
    name: StrictStr = Field(description="Name of the badgeclass")
    type: StrictStr = Field(description="BadgeClass")
    __properties: ClassVar[List[str]] = ["alignment", "coursefullname", "courseid", "criteriaNarrative", "criteriaUrl", "description", "hostedUrl", "id", "image", "issuer", "name", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreBadgesGetBadgeResponseBadge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in alignment (list)
        _items = []
        if self.alignment:
            for _item_alignment in self.alignment:
                if _item_alignment:
                    _items.append(_item_alignment.to_dict())
            _dict['alignment'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreBadgesGetBadgeResponseBadge from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreBadgesGetBadgeResponseBadge" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "alignment": [CoreBadgesGetBadgeResponseBadgeAlignmentInner.from_dict(_item) for _item in obj["alignment"]] if obj.get("alignment") is not None else None,
            "coursefullname": obj.get("coursefullname") if obj.get("coursefullname") is not None else '',
            "courseid": obj.get("courseid") if obj.get("courseid") is not None else 0,
            "criteriaNarrative": obj.get("criteriaNarrative") if obj.get("criteriaNarrative") is not None else '',
            "criteriaUrl": obj.get("criteriaUrl") if obj.get("criteriaUrl") is not None else '',
            "description": obj.get("description") if obj.get("description") is not None else '',
            "hostedUrl": obj.get("hostedUrl") if obj.get("hostedUrl") is not None else '',
            "id": obj.get("id") if obj.get("id") is not None else '',
            "image": obj.get("image") if obj.get("image") is not None else '',
            "issuer": obj.get("issuer") if obj.get("issuer") is not None else '',
            "name": obj.get("name") if obj.get("name") is not None else '',
            "type": obj.get("type") if obj.get("type") is not None else ''
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_average import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_contributiontocoursetotal import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_feedback import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_grade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_itemname import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_leader import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_lettergrade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_percentage import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_range import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_rank import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_weight import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class GradereportUserGetGradesTableResponseTablesInnerTabledataInner(BaseModel):
    """
    table
    """ # noqa: E501
    average: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage] = None
    contributiontocoursetotal: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal] = None
    feedback: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback] = None
    grade: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade] = None
    itemname: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname] = None
    leader: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader] = None
    lettergrade: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade] = None
    parentcategories: List[Optional[StrictInt]]
    percentage: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage] = None
    range: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange] = None
    rank: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank] = None
    weight: Optional[GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight] = None
    __properties: ClassVar[List[str]] = ["average", "contributiontocoursetotal", "feedback", "grade", "itemname", "leader", "lettergrade", "parentcategories", "percentage", "range", "rank", "weight"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GradereportUserGetGradesTableResponseTablesInnerTabledataInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of average
        if self.average:
            _dict['average'] = self.average.to_dict()
        # override the default output from pydantic by calling `to_dict()` of contributiontocoursetotal
        if self.contributiontocoursetotal:
            _dict['contributiontocoursetotal'] = self.contributiontocoursetotal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of feedback
        if self.feedback:
            _dict['feedback'] = self.feedback.to_dict()
        # override the default output from pydantic by calling `to_dict()` of grade
        if self.grade:
            _dict['grade'] = self.grade.to_dict()
        # override the default output from pydantic by calling `to_dict()` of itemname
        if self.itemname:
            _dict['itemname'] = self.itemname.to_dict()
        # override the default output from pydantic by calling `to_dict()` of leader
        if self.leader:
            _dict['leader'] = self.leader.to_dict()
        # override the default output from pydantic by calling `to_dict()` of lettergrade
        if self.lettergrade:
            _dict['lettergrade'] = self.lettergrade.to_dict()
        # override the default output from pydantic by calling `to_dict()` of percentage
        if self.percentage:
            _dict['percentage'] = self.percentage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of range
        if self.range:
            _dict['range'] = self.range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rank
        if self.rank:
            _dict['rank'] = self.rank.to_dict()
        # override the default output from pydantic by calling `to_dict()` of weight
        if self.weight:
            _dict['weight'] = self.weight.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GradereportUserGetGradesTableResponseTablesInnerTabledataInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "GradereportUserGetGradesTableResponseTablesInnerTabledataInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "average": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage.from_dict(obj["average"]) if obj.get("average") is not None else None,
            "contributiontocoursetotal": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal.from_dict(obj["contributiontocoursetotal"]) if obj.get("contributiontocoursetotal") is not None else None,
            "feedback": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback.from_dict(obj["feedback"]) if obj.get("feedback") is not None else None,
            "grade": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade.from_dict(obj["grade"]) if obj.get("grade") is not None else None,
            "itemname": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname.from_dict(obj["itemname"]) if obj.get("itemname") is not None else None,
            "leader": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader.from_dict(obj["leader"]) if obj.get("leader") is not None else None,
            "lettergrade": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade.from_dict(obj["lettergrade"]) if obj.get("lettergrade") is not None else None,
            "parentcategories": obj.get("parentcategories"),
            "percentage": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage.from_dict(obj["percentage"]) if obj.get("percentage") is not None else None,
            "range": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange.from_dict(obj["range"]) if obj.get("range") is not None else None,
            "rank": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank.from_dict(obj["rank"]) if obj.get("rank") is not None else None,
            "weight": GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight.from_dict(obj["weight"]) if obj.get("weight") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModFeedbackGetAnalysisResponseItemsdataInnerItem(BaseModel):
    """
    ModFeedbackGetAnalysisResponseItemsdataInnerItem
    """ # noqa: E501
    dependitem: StrictInt = Field(description="The item id this item depend on.")
    dependvalue: StrictStr = Field(description="The depend value.")
    feedback: StrictInt = Field(description="The feedback instance id this records belongs to.")
    hasvalue: StrictInt = Field(description="Whether it has a value or not.")
    id: StrictInt = Field(description="The record id.")
    itemfiles: List[CoreCompetencyReadUserEvidenceResponseFilesInner] = Field(description="itemfiles")
    itemnumber: Optional[StrictInt] = Field(description="The item position number")
    label: StrictStr = Field(description="The item label.")
    name: StrictStr = Field(description="The item name.")
    nameformat: Optional[StrictInt] = Field(default=1, description="name format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    options: StrictStr = Field(description="Different additional settings for the item (question).")
    otherdata: Optional[StrictStr] = Field(description="Additional data that may be required by external functions")
    position: StrictInt = Field(description="The position in the list of questions.")
    presentation: StrictStr = Field(description="The text describing the item or the available possible answers.")
    presentationformat: Optional[StrictInt] = Field(default=1, description="presentation format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    required: StrictBool = Field(description="Whether is a item (question) required or not.")
    template: StrictInt = Field(description="If it belogns to a template, the template id.")
    typ: StrictStr = Field(description="The type of the item.")
    __properties: ClassVar[List[str]] = ["dependitem", "dependvalue", "feedback", "hasvalue", "id", "itemfiles", "itemnumber", "label", "name", "nameformat", "options", "otherdata", "position", "presentation", "presentationformat", "required", "template", "typ"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModFeedbackGetAnalysisResponseItemsdataInnerItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in itemfiles (list)
        _items = []
        if self.itemfiles:
            for _item_itemfiles in self.itemfiles:
                if _item_itemfiles:
                    _items.append(_item_itemfiles.to_dict())
            _dict['itemfiles'] = _items
        # set to None if itemnumber (nullable) is None
        # and model_fields_set contains the field
        if self.itemnumber is None and "itemnumber" in self.model_fields_set:
            _dict['itemnumber'] = None

        # set to None if nameformat (nullable) is None
        # and model_fields_set contains the field
        if self.nameformat is None and "nameformat" in self.model_fields_set:
            _dict['nameformat'] = None

        # set to None if otherdata (nullable) is None
        # and model_fields_set contains the field
        if self.otherdata is None and "otherdata" in self.model_fields_set:
            _dict['otherdata'] = None

        # set to None if presentationformat (nullable) is None
        # and model_fields_set contains the field
        if self.presentationformat is None and "presentationformat" in self.model_fields_set:
            _dict['presentationformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModFeedbackGetAnalysisResponseItemsdataInnerItem from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModFeedbackGetAnalysisResponseItemsdataInnerItem" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "dependitem": obj.get("dependitem") if obj.get("dependitem") is not None else 0,
            "dependvalue": obj.get("dependvalue") if obj.get("dependvalue") is not None else '',
            "feedback": obj.get("feedback") if obj.get("feedback") is not None else 0,
            "hasvalue": obj.get("hasvalue") if obj.get("hasvalue") is not None else 0,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "itemfiles": [CoreCompetencyReadUserEvidenceResponseFilesInner.from_dict(_item) for _item in obj["itemfiles"]] if obj.get("itemfiles") is not None else None,
            "itemnumber": obj.get("itemnumber"),
            "label": obj.get("label") if obj.get("label") is not None else '',
            "name": obj.get("name") if obj.get("name") is not None else '',
            "nameformat": obj.get("nameformat") if obj.get("nameformat") is not None else 1,
            "options": obj.get("options") if obj.get("options") is not None else '',
            "otherdata": obj.get("otherdata"),
            "position": obj.get("position") if obj.get("position") is not None else 0,
            "presentation": obj.get("presentation") if obj.get("presentation") is not None else '',
            "presentationformat": obj.get("presentationformat") if obj.get("presentationformat") is not None else 1,
            "required": obj.get("required") if obj.get("required") is not None else False,
            "template": obj.get("template") if obj.get("template") is not None else 0,
            "typ": obj.get("typ") if obj.get("typ") is not None else ''
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModScormGetScormsByCoursesResponseScormsInner(BaseModel):
    """
    SCORM
    """ # noqa: E501
    auto: Optional[StrictBool] = Field(default=None, description="Auto continue?")
    autocommit: Optional[StrictBool] = Field(default=None, description="Save track data automatically?")
    completionscorerequired: Optional[StrictInt] = Field(default=None, description="Minimum score required")
    completionstatusallscos: Optional[StrictInt] = Field(default=None, description="Require all scos to return completion status")
    completionstatusrequired: Optional[StrictInt] = Field(default=None, description="Status passed/completed required?")
    course: Optional[StrictInt] = Field(description="Course id")
    coursemodule: Optional[StrictInt] = Field(description="Course module id")
    displayattemptstatus: Optional[StrictInt] = Field(default=None, description="How to display attempt status")
    displaycoursestructure: Optional[StrictBool] = Field(default=None, description="Display contents structure")
    forcecompleted: Optional[StrictBool] = Field(default=None, description="Status current attempt is forced to \"completed\"")
    forcenewattempt: Optional[StrictInt] = Field(default=None, description="Controls re-entry behaviour")
    grademethod: Optional[StrictInt] = Field(default=None, description="Grade method")
    groupingid: Optional[StrictInt] = Field(default=None, description="Group id")
    groupmode: Optional[StrictInt] = Field(default=None, description="Group mode")
    height: Optional[StrictInt] = Field(default=None, description="Frame height")
    hidebrowse: Optional[StrictBool] = Field(default=None, description="Disable preview mode?")
    hidetoc: Optional[StrictInt] = Field(default=None, description="How to display the SCORM structure in player")
    id: Optional[StrictInt] = Field(description="Activity instance id")
    intro: Optional[StrictStr] = Field(description="Activity introduction")
    introfiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="Files in the introduction")
    introformat: Optional[StrictInt] = Field(description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    lang: Optional[StrictStr] = Field(default=None, description="Forced activity language")
    lastattemptlock: Optional[StrictBool] = Field(default=None, description="Prevents to launch new attempts once finished")
    launch: Optional[StrictInt] = Field(default=None, description="First content to launch")
    maxattempt: Optional[StrictInt] = Field(default=None, description="Maximum number of attemtps")
    maxgrade: Optional[StrictInt] = Field(default=None, description="Max grade")
    md5hash: Optional[StrictStr] = Field(default=None, description="MD5 Hash of package file")
    name: Optional[StrictStr] = Field(description="Activity name")
    nav: Optional[StrictInt] = Field(default=None, description="Show navigation buttons")
    navpositionleft: Optional[StrictInt] = Field(default=None, description="Navigation position left")
    navpositiontop: Optional[StrictInt] = Field(default=None, description="Navigation position top")
    options: Optional[StrictStr] = Field(default=None, description="Additional options")
    packagesize: Optional[StrictInt] = Field(default=None, description="SCORM zip package size")
    packageurl: Optional[StrictStr] = Field(default=None, description="SCORM zip package URL")
    popup: Optional[StrictInt] = Field(default=None, description="Display in current or new window")
    protectpackagedownloads: Optional[StrictBool] = Field(default=None, description="Protect package downloads?")
    reference: Optional[StrictStr] = Field(default=None, description="Reference to the package")
    revision: Optional[StrictInt] = Field(default=None, description="Revison number")
    scormtype: Optional[StrictStr] = Field(default=None, description="SCORM type")
    section: Optional[StrictInt] = Field(default=None, description="Course section id")
    sha1hash: Optional[StrictStr] = Field(default=None, description="Package content or ext path hash")
    skipview: Optional[StrictInt] = Field(default=None, description="How to skip the content structure page")
    timeclose: Optional[StrictInt] = Field(default=None, description="Available to")
    timemodified: Optional[StrictInt] = Field(default=None, description="Time of last modification")
    timeopen: Optional[StrictInt] = Field(default=None, description="Available from")
    updatefreq: Optional[StrictInt] = Field(default=None, description="Auto-update frequency for remote packages")
    version: Optional[StrictStr] = Field(default=None, description="SCORM version (SCORM_12, SCORM_13, SCORM_AICC)")
    visible: Optional[StrictBool] = Field(default=None, description="Visible")
    whatgrade: Optional[StrictInt] = Field(default=None, description="What grade")
    width: Optional[StrictInt] = Field(default=None, description="Frame width")
    __properties: ClassVar[List[str]] = ["auto", "autocommit", "completionscorerequired", "completionstatusallscos", "completionstatusrequired", "course", "coursemodule", "displayattemptstatus", "displaycoursestructure", "forcecompleted", "forcenewattempt", "grademethod", "groupingid", "groupmode", "height", "hidebrowse", "hidetoc", "id", "intro", "introfiles", "introformat", "lang", "lastattemptlock", "launch", "maxattempt", "maxgrade", "md5hash", "name", "nav", "navpositionleft", "navpositiontop", "options", "packagesize", "packageurl", "popup", "protectpackagedownloads", "reference", "revision", "scormtype", "section", "sha1hash", "skipview", "timeclose", "timemodified", "timeopen", "updatefreq", "version", "visible", "whatgrade", "width"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModScormGetScormsByCoursesResponseScormsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if auto (nullable) is None
        # and model_fields_set contains the field
        if self.auto is None and "auto" in self.model_fields_set:
            _dict['auto'] = None

        # set to None if autocommit (nullable) is None
        # and model_fields_set contains the field
        if self.autocommit is None and "autocommit" in self.model_fields_set:
            _dict['autocommit'] = None

        # set to None if completionscorerequired (nullable) is None
        # and model_fields_set contains the field
        if self.completionscorerequired is None and "completionscorerequired" in self.model_fields_set:
            _dict['completionscorerequired'] = None

        # set to None if completionstatusallscos (nullable) is None
        # and model_fields_set contains the field
        if self.completionstatusallscos is None and "completionstatusallscos" in self.model_fields_set:
            _dict['completionstatusallscos'] = None

        # set to None if completionstatusrequired (nullable) is None
        # and model_fields_set contains the field
        if self.completionstatusrequired is None and "completionstatusrequired" in self.model_fields_set:
            _dict['completionstatusrequired'] = None

        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if coursemodule (nullable) is None
        # and model_fields_set contains the field
        if self.coursemodule is None and "coursemodule" in self.model_fields_set:
            _dict['coursemodule'] = None

        # set to None if displayattemptstatus (nullable) is None
        # and model_fields_set contains the field
        if self.displayattemptstatus is None and "displayattemptstatus" in self.model_fields_set:
            _dict['displayattemptstatus'] = None

        # set to None if displaycoursestructure (nullable) is None
        # and model_fields_set contains the field
        if self.displaycoursestructure is None and "displaycoursestructure" in self.model_fields_set:
            _dict['displaycoursestructure'] = None

        # set to None if forcecompleted (nullable) is None
        # and model_fields_set contains the field
        if self.forcecompleted is None and "forcecompleted" in self.model_fields_set:
            _dict['forcecompleted'] = None

        # set to None if forcenewattempt (nullable) is None
        # and model_fields_set contains the field
        if self.forcenewattempt is None and "forcenewattempt" in self.model_fields_set:
            _dict['forcenewattempt'] = None

        # set to None if grademethod (nullable) is None
        # and model_fields_set contains the field
        if self.grademethod is None and "grademethod" in self.model_fields_set:
            _dict['grademethod'] = None

        # set to None if groupingid (nullable) is None
        # and model_fields_set contains the field
        if self.groupingid is None and "groupingid" in self.model_fields_set:
            _dict['groupingid'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if height (nullable) is None
        # and model_fields_set contains the field
        if self.height is None and "height" in self.model_fields_set:
            _dict['height'] = None

        # set to None if hidebrowse (nullable) is None
        # and model_fields_set contains the field
        if self.hidebrowse is None and "hidebrowse" in self.model_fields_set:
            _dict['hidebrowse'] = None

        # set to None if hidetoc (nullable) is None
        # and model_fields_set contains the field
        if self.hidetoc is None and "hidetoc" in self.model_fields_set:
            _dict['hidetoc'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if intro (nullable) is None
        # and model_fields_set contains the field
        if self.intro is None and "intro" in self.model_fields_set:
            _dict['intro'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if lastattemptlock (nullable) is None
        # and model_fields_set contains the field
        if self.lastattemptlock is None and "lastattemptlock" in self.model_fields_set:
            _dict['lastattemptlock'] = None

        # set to None if launch (nullable) is None
        # and model_fields_set contains the field
        if self.launch is None and "launch" in self.model_fields_set:
            _dict['launch'] = None

        # set to None if maxattempt (nullable) is None
        # and model_fields_set contains the field
        if self.maxattempt is None and "maxattempt" in self.model_fields_set:
            _dict['maxattempt'] = None

        # set to None if maxgrade (nullable) is None
        # and model_fields_set contains the field
        if self.maxgrade is None and "maxgrade" in self.model_fields_set:
            _dict['maxgrade'] = None

        # set to None if md5hash (nullable) is None
        # and model_fields_set contains the field
        if self.md5hash is None and "md5hash" in self.model_fields_set:
            _dict['md5hash'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if nav (nullable) is None
        # and model_fields_set contains the field
        if self.nav is None and "nav" in self.model_fields_set:
            _dict['nav'] = None

        # set to None if navpositionleft (nullable) is None
        # and model_fields_set contains the field
        if self.navpositionleft is None and "navpositionleft" in self.model_fields_set:
            _dict['navpositionleft'] = None

        # set to None if navpositiontop (nullable) is None
        # and model_fields_set contains the field
        if self.navpositiontop is None and "navpositiontop" in self.model_fields_set:
            _dict['navpositiontop'] = None

        # set to None if options (nullable) is None
        # and model_fields_set contains the field
        if self.options is None and "options" in self.model_fields_set:
            _dict['options'] = None

        # set to None if packagesize (nullable) is None
        # and model_fields_set contains the field
        if self.packagesize is None and "packagesize" in self.model_fields_set:
            _dict['packagesize'] = None

        # set to None if packageurl (nullable) is None
        # and model_fields_set contains the field
        if self.packageurl is None and "packageurl" in self.model_fields_set:
            _dict['packageurl'] = None

        # set to None if popup (nullable) is None
        # and model_fields_set contains the field
        if self.popup is None and "popup" in self.model_fields_set:
            _dict['popup'] = None

        # set to None if protectpackagedownloads (nullable) is None
        # and model_fields_set contains the field
        if self.protectpackagedownloads is None and "protectpackagedownloads" in self.model_fields_set:
            _dict['protectpackagedownloads'] = None

        # set to None if reference (nullable) is None
        # and model_fields_set contains the field
        if self.reference is None and "reference" in self.model_fields_set:
            _dict['reference'] = None

        # set to None if revision (nullable) is None
        # and model_fields_set contains the field
        if self.revision is None and "revision" in self.model_fields_set:
            _dict['revision'] = None

        # set to None if scormtype (nullable) is None
        # and model_fields_set contains the field
        if self.scormtype is None and "scormtype" in self.model_fields_set:
            _dict['scormtype'] = None

        # set to None if section (nullable) is None
        # and model_fields_set contains the field
        if self.section is None and "section" in self.model_fields_set:
            _dict['section'] = None

        # set to None if sha1hash (nullable) is None
        # and model_fields_set contains the field
        if self.sha1hash is None and "sha1hash" in self.model_fields_set:
            _dict['sha1hash'] = None

        # set to None if skipview (nullable) is None
        # and model_fields_set contains the field
        if self.skipview is None and "skipview" in self.model_fields_set:
            _dict['skipview'] = None

        # set to None if timeclose (nullable) is None
        # and model_fields_set contains the field
        if self.timeclose is None and "timeclose" in self.model_fields_set:
            _dict['timeclose'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if timeopen (nullable) is None
        # and model_fields_set contains the field
        if self.timeopen is None and "timeopen" in self.model_fields_set:
            _dict['timeopen'] = None

        # set to None if updatefreq (nullable) is None
        # and model_fields_set contains the field
        if self.updatefreq is None and "updatefreq" in self.model_fields_set:
            _dict['updatefreq'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        # set to None if whatgrade (nullable) is None
        # and model_fields_set contains the field
        if self.whatgrade is None and "whatgrade" in self.model_fields_set:
            _dict['whatgrade'] = None

        # set to None if width (nullable) is None
        # and model_fields_set contains the field
        if self.width is None and "width" in self.model_fields_set:
            _dict['width'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModScormGetScormsByCoursesResponseScormsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModScormGetScormsByCoursesResponseScormsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "auto": obj.get("auto"),
            "autocommit": obj.get("autocommit"),
            "completionscorerequired": obj.get("completionscorerequired"),
            "completionstatusallscos": obj.get("completionstatusallscos"),
            "completionstatusrequired": obj.get("completionstatusrequired"),
            "course": obj.get("course"),
            "coursemodule": obj.get("coursemodule"),
            "displayattemptstatus": obj.get("displayattemptstatus"),
            "displaycoursestructure": obj.get("displaycoursestructure"),
            "forcecompleted": obj.get("forcecompleted"),
            "forcenewattempt": obj.get("forcenewattempt"),
            "grademethod": obj.get("grademethod"),
            "groupingid": obj.get("groupingid"),
            "groupmode": obj.get("groupmode"),
            "height": obj.get("height"),
            "hidebrowse": obj.get("hidebrowse"),
            "hidetoc": obj.get("hidetoc"),
            "id": obj.get("id"),
            "intro": obj.get("intro"),
            "introfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat"),
            "lang": obj.get("lang"),
            "lastattemptlock": obj.get("lastattemptlock"),
            "launch": obj.get("launch"),
            "maxattempt": obj.get("maxattempt"),
            "maxgrade": obj.get("maxgrade"),
            "md5hash": obj.get("md5hash"),
            "name": obj.get("name"),
            "nav": obj.get("nav"),
            "navpositionleft": obj.get("navpositionleft"),
            "navpositiontop": obj.get("navpositiontop"),
            "options": obj.get("options"),
            "packagesize": obj.get("packagesize"),
            "packageurl": obj.get("packageurl"),
            "popup": obj.get("popup"),
            "protectpackagedownloads": obj.get("protectpackagedownloads"),
            "reference": obj.get("reference"),
            "revision": obj.get("revision"),
            "scormtype": obj.get("scormtype"),
            "section": obj.get("section"),
            "sha1hash": obj.get("sha1hash"),
            "skipview": obj.get("skipview"),
            "timeclose": obj.get("timeclose"),
            "timemodified": obj.get("timemodified"),
            "timeopen": obj.get("timeopen"),
            "updatefreq": obj.get("updatefreq"),
            "version": obj.get("version"),
            "visible": obj.get("visible"),
            "whatgrade": obj.get("whatgrade"),
            "width": obj.get("width")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_message_get_contact_requests_response_inner import CoreMessageGetContactRequestsResponseInner
from poodle_async_full.models.core_message_get_conversation_between_users_response_messages_inner import CoreMessageGetConversationBetweenUsersResponseMessagesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreMessageGetConversationBetweenUsersResponse(BaseModel):
    """
    CoreMessageGetConversationBetweenUsersResponse
    """ # noqa: E501
    candeletemessagesforallusers: Optional[StrictBool] = Field(default=False, description="If the user can delete messages in the conversation for all users")
    id: Optional[StrictInt] = Field(description="The conversation id")
    imageurl: Optional[StrictStr] = Field(default=None, description="A link to the conversation picture, if set")
    isfavourite: Optional[StrictBool] = Field(description="If the user marked this conversation as a favourite")
    ismuted: Optional[StrictBool] = Field(description="If the user muted this conversation")
    isread: Optional[StrictBool] = Field(description="If the user has read all messages in the conversation")
    membercount: Optional[StrictInt] = Field(description="Total number of conversation members")
    members: List[CoreMessageGetContactRequestsResponseInner]
    messages: List[CoreMessageGetConversationBetweenUsersResponseMessagesInner]
    name: Optional[StrictStr] = Field(default=None, description="The conversation name, if set")
    subname: Optional[StrictStr] = Field(default=None, description="A subtitle for the conversation name, if set")
    type: Optional[StrictInt] = Field(description="The type of the conversation (1=individual,2=group,3=self)")
    unreadcount: Optional[StrictInt] = Field(default=None, description="The number of unread messages in this conversation")
    __properties: ClassVar[List[str]] = ["candeletemessagesforallusers", "id", "imageurl", "isfavourite", "ismuted", "isread", "membercount", "members", "messages", "name", "subname", "type", "unreadcount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreMessageGetConversationBetweenUsersResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item_members in self.members:
                if _item_members:
                    _items.append(_item_members.to_dict())
            _dict['members'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item_messages in self.messages:
                if _item_messages:
                    _items.append(_item_messages.to_dict())
            _dict['messages'] = _items
        # set to None if candeletemessagesforallusers (nullable) is None
        # and model_fields_set contains the field
        if self.candeletemessagesforallusers is None and "candeletemessagesforallusers" in self.model_fields_set:
            _dict['candeletemessagesforallusers'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if imageurl (nullable) is None
        # and model_fields_set contains the field
        if self.imageurl is None and "imageurl" in self.model_fields_set:
            _dict['imageurl'] = None

        # set to None if isfavourite (nullable) is None
        # and model_fields_set contains the field
        if self.isfavourite is None and "isfavourite" in self.model_fields_set:
            _dict['isfavourite'] = None

        # set to None if ismuted (nullable) is None
        # and model_fields_set contains the field
        if self.ismuted is None and "ismuted" in self.model_fields_set:
            _dict['ismuted'] = None

        # set to None if isread (nullable) is None
        # and model_fields_set contains the field
        if self.isread is None and "isread" in self.model_fields_set:
            _dict['isread'] = None

        # set to None if membercount (nullable) is None
        # and model_fields_set contains the field
        if self.membercount is None and "membercount" in self.model_fields_set:
            _dict['membercount'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if subname (nullable) is None
        # and model_fields_set contains the field
        if self.subname is None and "subname" in self.model_fields_set:
            _dict['subname'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if unreadcount (nullable) is None
        # and model_fields_set contains the field
        if self.unreadcount is None and "unreadcount" in self.model_fields_set:
            _dict['unreadcount'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreMessageGetConversationBetweenUsersResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreMessageGetConversationBetweenUsersResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "candeletemessagesforallusers": obj.get("candeletemessagesforallusers") if obj.get("candeletemessagesforallusers") is not None else False,
            "id": obj.get("id"),
            "imageurl": obj.get("imageurl"),
            "isfavourite": obj.get("isfavourite"),
            "ismuted": obj.get("ismuted"),
            "isread": obj.get("isread"),
            "membercount": obj.get("membercount"),
            "members": [CoreMessageGetContactRequestsResponseInner.from_dict(_item) for _item in obj["members"]] if obj.get("members") is not None else None,
            "messages": [CoreMessageGetConversationBetweenUsersResponseMessagesInner.from_dict(_item) for _item in obj["messages"]] if obj.get("messages") is not None else None,
            "name": obj.get("name"),
            "subname": obj.get("subname"),
            "type": obj.get("type"),
            "unreadcount": obj.get("unreadcount")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModDataGetFieldsResponseFieldsInner(BaseModel):
    """
    ModDataGetFieldsResponseFieldsInner
    """ # noqa: E501
    dataid: StrictInt = Field(description="The field type of the content.")
    description: StrictStr = Field(description="The field description.")
    id: StrictInt = Field(description="Field id.")
    name: StrictStr = Field(description="The field name.")
    param1: Optional[StrictStr] = Field(description="Field parameters")
    param10: Optional[StrictStr] = Field(description="Field parameters")
    param2: Optional[StrictStr] = Field(description="Field parameters")
    param3: Optional[StrictStr] = Field(description="Field parameters")
    param4: Optional[StrictStr] = Field(description="Field parameters")
    param5: Optional[StrictStr] = Field(description="Field parameters")
    param6: Optional[StrictStr] = Field(description="Field parameters")
    param7: Optional[StrictStr] = Field(description="Field parameters")
    param8: Optional[StrictStr] = Field(description="Field parameters")
    param9: Optional[StrictStr] = Field(description="Field parameters")
    required: StrictBool = Field(description="Whether is a field required or not.")
    type: StrictStr = Field(description="The field type.")
    __properties: ClassVar[List[str]] = ["dataid", "description", "id", "name", "param1", "param10", "param2", "param3", "param4", "param5", "param6", "param7", "param8", "param9", "required", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModDataGetFieldsResponseFieldsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if param1 (nullable) is None
        # and model_fields_set contains the field
        if self.param1 is None and "param1" in self.model_fields_set:
            _dict['param1'] = None

        # set to None if param10 (nullable) is None
        # and model_fields_set contains the field
        if self.param10 is None and "param10" in self.model_fields_set:
            _dict['param10'] = None

        # set to None if param2 (nullable) is None
        # and model_fields_set contains the field
        if self.param2 is None and "param2" in self.model_fields_set:
            _dict['param2'] = None

        # set to None if param3 (nullable) is None
        # and model_fields_set contains the field
        if self.param3 is None and "param3" in self.model_fields_set:
            _dict['param3'] = None

        # set to None if param4 (nullable) is None
        # and model_fields_set contains the field
        if self.param4 is None and "param4" in self.model_fields_set:
            _dict['param4'] = None

        # set to None if param5 (nullable) is None
        # and model_fields_set contains the field
        if self.param5 is None and "param5" in self.model_fields_set:
            _dict['param5'] = None

        # set to None if param6 (nullable) is None
        # and model_fields_set contains the field
        if self.param6 is None and "param6" in self.model_fields_set:
            _dict['param6'] = None

        # set to None if param7 (nullable) is None
        # and model_fields_set contains the field
        if self.param7 is None and "param7" in self.model_fields_set:
            _dict['param7'] = None

        # set to None if param8 (nullable) is None
        # and model_fields_set contains the field
        if self.param8 is None and "param8" in self.model_fields_set:
            _dict['param8'] = None

        # set to None if param9 (nullable) is None
        # and model_fields_set contains the field
        if self.param9 is None and "param9" in self.model_fields_set:
            _dict['param9'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModDataGetFieldsResponseFieldsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModDataGetFieldsResponseFieldsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "dataid": obj.get("dataid") if obj.get("dataid") is not None else 0,
            "description": obj.get("description") if obj.get("description") is not None else '',
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "param1": obj.get("param1"),
            "param10": obj.get("param10"),
            "param2": obj.get("param2"),
            "param3": obj.get("param3"),
            "param4": obj.get("param4"),
            "param5": obj.get("param5"),
            "param6": obj.get("param6"),
            "param7": obj.get("param7"),
            "param8": obj.get("param8"),
            "param9": obj.get("param9"),
            "required": obj.get("required") if obj.get("required") is not None else False,
            "type": obj.get("type") if obj.get("type") is not None else ''
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class AuthEmailGetSignupSettingsResponseProfilefieldsInner(BaseModel):
    """
    AuthEmailGetSignupSettingsResponseProfilefieldsInner
    """ # noqa: E501
    categoryid: Optional[StrictInt] = Field(default=None, description="Profield field category id")
    categoryname: Optional[StrictStr] = Field(default=None, description="Profield field category name")
    datatype: Optional[StrictStr] = Field(default=None, description="Profield field datatype")
    defaultdata: Optional[StrictStr] = Field(default=None, description="Profield field default data")
    defaultdataformat: Optional[StrictInt] = Field(description="defaultdata format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    description: Optional[StrictStr] = Field(default=None, description="Profield field description")
    descriptionformat: Optional[StrictInt] = Field(description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    forceunique: Optional[StrictInt] = Field(default=None, description="Profield field unique")
    id: Optional[StrictInt] = Field(default=None, description="Profile field id")
    locked: Optional[StrictInt] = Field(default=None, description="Profield field locked")
    name: Optional[StrictStr] = Field(default=None, description="Profield field name")
    param1: Optional[StrictStr] = Field(default=None, description="Profield field settings")
    param2: Optional[StrictStr] = Field(default=None, description="Profield field settings")
    param3: Optional[StrictStr] = Field(default=None, description="Profield field settings")
    param4: Optional[StrictStr] = Field(default=None, description="Profield field settings")
    param5: Optional[StrictStr] = Field(default=None, description="Profield field settings")
    required: Optional[StrictInt] = Field(default=None, description="Profield field required")
    shortname: Optional[StrictStr] = Field(default=None, description="Profile field shortname")
    signup: Optional[StrictInt] = Field(default=None, description="Profield field in signup form")
    sortorder: Optional[StrictInt] = Field(default=None, description="Profield field sort order")
    visible: Optional[StrictInt] = Field(default=None, description="Profield field visible")
    __properties: ClassVar[List[str]] = ["categoryid", "categoryname", "datatype", "defaultdata", "defaultdataformat", "description", "descriptionformat", "forceunique", "id", "locked", "name", "param1", "param2", "param3", "param4", "param5", "required", "shortname", "signup", "sortorder", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuthEmailGetSignupSettingsResponseProfilefieldsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if categoryid (nullable) is None
        # and model_fields_set contains the field
        if self.categoryid is None and "categoryid" in self.model_fields_set:
            _dict['categoryid'] = None

        # set to None if categoryname (nullable) is None
        # and model_fields_set contains the field
        if self.categoryname is None and "categoryname" in self.model_fields_set:
            _dict['categoryname'] = None

        # set to None if datatype (nullable) is None
        # and model_fields_set contains the field
        if self.datatype is None and "datatype" in self.model_fields_set:
            _dict['datatype'] = None

        # set to None if defaultdata (nullable) is None
        # and model_fields_set contains the field
        if self.defaultdata is None and "defaultdata" in self.model_fields_set:
            _dict['defaultdata'] = None

        # set to None if defaultdataformat (nullable) is None
        # and model_fields_set contains the field
        if self.defaultdataformat is None and "defaultdataformat" in self.model_fields_set:
            _dict['defaultdataformat'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if forceunique (nullable) is None
        # and model_fields_set contains the field
        if self.forceunique is None and "forceunique" in self.model_fields_set:
            _dict['forceunique'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if locked (nullable) is None
        # and model_fields_set contains the field
        if self.locked is None and "locked" in self.model_fields_set:
            _dict['locked'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if param1 (nullable) is None
        # and model_fields_set contains the field
        if self.param1 is None and "param1" in self.model_fields_set:
            _dict['param1'] = None

        # set to None if param2 (nullable) is None
        # and model_fields_set contains the field
        if self.param2 is None and "param2" in self.model_fields_set:
            _dict['param2'] = None

        # set to None if param3 (nullable) is None
        # and model_fields_set contains the field
        if self.param3 is None and "param3" in self.model_fields_set:
            _dict['param3'] = None

        # set to None if param4 (nullable) is None
        # and model_fields_set contains the field
        if self.param4 is None and "param4" in self.model_fields_set:
            _dict['param4'] = None

        # set to None if param5 (nullable) is None
        # and model_fields_set contains the field
        if self.param5 is None and "param5" in self.model_fields_set:
            _dict['param5'] = None

        # set to None if required (nullable) is None
        # and model_fields_set contains the field
        if self.required is None and "required" in self.model_fields_set:
            _dict['required'] = None

        # set to None if shortname (nullable) is None
        # and model_fields_set contains the field
        if self.shortname is None and "shortname" in self.model_fields_set:
            _dict['shortname'] = None

        # set to None if signup (nullable) is None
        # and model_fields_set contains the field
        if self.signup is None and "signup" in self.model_fields_set:
            _dict['signup'] = None

        # set to None if sortorder (nullable) is None
        # and model_fields_set contains the field
        if self.sortorder is None and "sortorder" in self.model_fields_set:
            _dict['sortorder'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuthEmailGetSignupSettingsResponseProfilefieldsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "AuthEmailGetSignupSettingsResponseProfilefieldsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "categoryid": obj.get("categoryid"),
            "categoryname": obj.get("categoryname"),
            "datatype": obj.get("datatype"),
            "defaultdata": obj.get("defaultdata"),
            "defaultdataformat": obj.get("defaultdataformat"),
            "description": obj.get("description"),
            "descriptionformat": obj.get("descriptionformat"),
            "forceunique": obj.get("forceunique"),
            "id": obj.get("id"),
            "locked": obj.get("locked"),
            "name": obj.get("name"),
            "param1": obj.get("param1"),
            "param2": obj.get("param2"),
            "param3": obj.get("param3"),
            "param4": obj.get("param4"),
            "param5": obj.get("param5"),
            "required": obj.get("required"),
            "shortname": obj.get("shortname"),
            "signup": obj.get("signup"),
            "sortorder": obj.get("sortorder"),
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


